diff --git a/README.markdown b/README.markdown
--- a/README.markdown
+++ b/README.markdown
@@ -30,6 +30,8 @@
 Changes
 -------
 
+0.1.5.0 - fix tests to work with language-javascript >= 0.5.14
+
 0.1.4.7 - remove upper bounds in cabal file
 
 0.1.4.6 - relax upper bound in optparse-applicative
diff --git a/hjsmin.cabal b/hjsmin.cabal
--- a/hjsmin.cabal
+++ b/hjsmin.cabal
@@ -1,5 +1,5 @@
 name:            hjsmin
-version:         0.1.4.8
+version:         0.1.5.0
 license:         BSD3
 license-file:    LICENSE
 author:          Alan Zimmerman <alan.zimm@gmail.com>
@@ -29,7 +29,7 @@
                    , blaze-builder       >= 0.2
                    , text                >= 0.8
                    , containers          >= 0.2
-                   , language-javascript >= 0.5.1
+                   , language-javascript >= 0.5.14
     exposed-modules: Text.Jasmine
     other-modules:   Text.Jasmine.Pretty
     ghc-options:     -Wall
@@ -43,7 +43,7 @@
                  , blaze-builder        >= 0.2
                  , text                 >= 0.8
                  , containers           >= 0.2
-                 , language-javascript  >= 0.5.1
+                 , language-javascript  >= 0.5.14
                  , optparse-applicative >= 0.7
 
 Test-Suite test-hjsmin
@@ -59,7 +59,7 @@
                  , blaze-builder       >= 0.2
                  , text                >= 0.8
                  , containers          >= 0.2
-                 , language-javascript >= 0.5.4
+                 , language-javascript >= 0.5.14
 
 source-repository head
   type:     git
diff --git a/runtests.hs b/runtests.hs
--- a/runtests.hs
+++ b/runtests.hs
@@ -234,9 +234,9 @@
   testMinify "this.cursor+=match[0].length" srcNestedSquare
 
 caseEitherLeft  =
-  -- Left "UnexpectedToken (MulToken {token_span = (AlexPn 2 1 3,'=',\"*SYNTAX*ERROR*\")})"
-  -- Left "\"MulToken {token_span = TokenPn 2 1 3, token_comment = [NoComment]}\""
-  Left "\"MulToken {token_span = TokenPn 2 1 3, token_comment = [NoComment]}\""
+  -- Left "UnexpectedToken (MulToken {tokenSpan = (AlexPn 2 1 3,'=',\"*SYNTAX*ERROR*\")})"
+  -- Left "\"MulToken {tokenSpan = TokenPn 2 1 3, tokenComment = [NoComment]}\""
+  Left "\"MulToken {tokenSpan = TokenPn 2 1 3, tokenComment = [NoComment]}\""
   @=? minifym (LB.fromChunks [(E.encodeUtf8 $ T.pack "a=*SYNTAX*ERROR*")])
 
 caseEitherRight  =
